summaryrefslogtreecommitdiffstats
path: root/WebCore/html/HTMLPlugInElement.h
diff options
context:
space:
mode:
Diffstat (limited to 'WebCore/html/HTMLPlugInElement.h')
-rw-r--r--WebCore/html/HTMLPlugInElement.h45
1 files changed, 24 insertions, 21 deletions
diff --git a/WebCore/html/HTMLPlugInElement.h b/WebCore/html/HTMLPlugInElement.h
index 5fad211..2b8c8ca 100644
--- a/WebCore/html/HTMLPlugInElement.h
+++ b/WebCore/html/HTMLPlugInElement.h
@@ -1,9 +1,7 @@
/*
- * This file is part of the DOM implementation for KDE.
- *
* Copyright (C) 1999 Lars Knoll (knoll@kde.org)
* (C) 1999 Antti Koivisto (koivisto@kde.org)
- * Copyright (C) 2004, 2006 Apple Computer, Inc.
+ * Copyright (C) 2004, 2006, 2007, 2008 Apple Inc. All rights reserved.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
@@ -27,16 +25,22 @@
#include "HTMLFrameOwnerElement.h"
-#if USE(JAVASCRIPTCORE_BINDINGS)
-#include <bindings/runtime.h>
+#if USE(JSC)
+namespace JSC {
+ namespace Bindings {
+ class Instance;
+ }
+}
#endif
-#if USE(NPOBJECT)
-#include <bindings/npruntime_internal.h>
+#if ENABLE(NETSCAPE_PLUGIN_API)
+struct NPObject;
#endif
namespace WebCore {
+class RenderWidget;
+
class HTMLPlugInElement : public HTMLFrameOwnerElement {
public:
HTMLPlugInElement(const QualifiedName& tagName, Document*);
@@ -62,32 +66,31 @@ public:
String width() const;
void setWidth(const String&);
-#if USE(JAVASCRIPTCORE_BINDINGS)
- virtual KJS::Bindings::Instance* getInstance() const = 0;
-#endif
-#if USE(NPOBJECT)
- virtual NPObject* getNPObject();
+ virtual void defaultEventHandler(Event*);
+
+ virtual RenderWidget* renderWidgetForJSBindings() const = 0;
+#if USE(JSC)
+ virtual void detach();
+ JSC::Bindings::Instance* getInstance() const;
#endif
- virtual void defaultEventHandler(Event*);
-private:
-#if USE(NPOBJECT)
- NPObject* createNPObject();
+#if ENABLE(NETSCAPE_PLUGIN_API)
+ virtual NPObject* getNPObject();
#endif
protected:
static void updateWidgetCallback(Node*);
- String oldNameAttr;
-#if USE(JAVASCRIPTCORE_BINDINGS)
- mutable RefPtr<KJS::Bindings::Instance> m_instance;
+ AtomicString m_name;
+#if USE(JSC)
+ mutable RefPtr<JSC::Bindings::Instance> m_instance;
#endif
-#if USE(NPOBJECT)
+#if ENABLE(NETSCAPE_PLUGIN_API)
NPObject* m_NPObject;
#endif
#ifdef ANDROID_FIX
// addressing webkit bug, http://bugs.webkit.org/show_bug.cgi?id=16512
// ensure the oldNameAttr and oldIdAttr are removed from HTMLDocument's NameCountMap
int oldNameIdCount;
#endif
};
@@ -62,32 +66,31 @@ public:
#ifdef ANDROID_FIX
// addressing webkit bug, http://bugs.webkit.org/show_bug.cgi?id=16512
- // ensure the oldNameAttr and oldIdAttr are removed from HTMLDocument's NameCountMap
+ // ensure that m_name is removed from HTMLDocument's NameCountMap
int oldNameIdCount;
#endif